@@ -1,7 +1,9 @@
 use bevy::{
     diagnostic::{Diagnostics, FrameTimeDiagnosticsPlugin},
+    math::Vec3A,
     prelude::*,
     render::primitives::Aabb,
+    window::PresentMode,
 };
 use bevy_mod_raycast::{
     DefaultPluginState, DefaultRaycastingPlugin, RayCastMesh, RayCastMethod, RayCastSource,
@@ -15,7 +17,7 @@ use bevy_mod_raycast::{
 fn main() {
     App::new()
         .insert_resource(WindowDescriptor {
-            vsync: false, // We'll turn off vsync for this example, as it's a source of input lag.
+            present_mode: PresentMode::Immediate, // We'll turn off vsync for this example, as it's a source of input lag.
             ..Default::default()
         })
         .add_plugins(DefaultPlugins)
@@ -201,7 +203,7 @@ fn manage_aabb(
             if enabled.0 {
                 commands.entity(entity).remove::<Aabb>();
             } else {
-                aabb.half_extents = Vec3::ONE * f32::MAX;
+                aabb.half_extents = Vec3A::ONE * f32::MAX;
             }
         }
     }
